@@ -720,8 +720,9 @@ gg.inla.mesh <- function(data,
                          mask = NULL,
                          nx = 500, ny = 500,
                          ...) {
+  requireNamespace("INLA")
   requireNamespace("ggplot2")
-  if (is.null(color) && ("colour" %in% ...names())) {
+  if (is.null(color) && ("colour" %in% names(list(...)))) {
     color <- list(...)[["colour"]]
   }
   if (!is.null(color)) {
@@ -852,6 +853,7 @@ gg.inla.mesh.1d <- function(data, mapping = ggplot2::aes(.data[["x"]], .data[["y
 #' @family geomes for Raster data
 #'
 #' @examples
+#' \dontrun{
 #' # Some features require the raster and spatstat.data packages.
 #' if (require("spatstat.data", quietly = TRUE) &&
 #'   require("raster", quietly = TRUE) &&
@@ -869,6 +871,7 @@ gg.inla.mesh.1d <- function(data, mapping = ggplot2::aes(.data[["x"]], .data[["y
 #'   ggplot() +
 #'     gg(elev)
 #' }
+#' }
 gg.RasterLayer <- function(data, mapping = ggplot2::aes(x = .data[["x"]], y = .data[["y"]], fill = .data[["layer"]]), ...) {
   requireNamespace("ggplot2")
   requireNamespace("raster")
