@@ -206,7 +206,13 @@ local_bru_safe_inla <- function(multicore = FALSE,
                                 envir = parent.frame()) {
   if (requireNamespace("INLA", quietly = TRUE)) {
     # Save the num.threads option so it can be restored
-    old_threads <- INLA::inla.getOption("num.threads")
+    old_threads <- tryCatch(
+      INLA::inla.getOption("num.threads"),
+      error = function(e) { e }
+    )
+    if (inherits(old_threads, "simpleError")) {
+      return(testthat::skip("inla.getOption() failed, skip INLA tests."))
+    }
     withr::defer(
       INLA::inla.setOption(num.threads = old_threads),
       envir
