@@ -71,7 +71,9 @@
 #'
 #' \donttest{
 #' # The INLA package and PROJ6 are required
-#' if (bru_safe_inla(quietly = TRUE) && fm_has_PROJ6()) {
+#' if (bru_safe_inla(quietly = TRUE) &&
+#'   fm_has_PROJ6() &&
+#'   require(ggplot2, quietly = TRUE)) {
 #'   data("gorillas", package = "inlabru")
 #'   pts <- sample.lgcp(gorillas$mesh,
 #'     loglambda = 1.5,
@@ -115,7 +117,7 @@ sample.lgcp <- function(mesh, loglambda, strategy = NULL, R = NULL, samplers = N
         points <- runif(n = Npoints, min = xmin, max = xmax)
         proj <- INLA::inla.mesh.project(mesh, points)
         if (length(loglambda) == 1) {
-          lambda_ratio <- exp(as.vector(rowSums(proj$A) * loglambda) - wmax)
+          lambda_ratio <- exp(as.vector(Matrix::rowSums(proj$A) * loglambda) - wmax)
         } else {
           lambda_ratio <- exp(as.vector(proj$A %*% loglambda) - wmax)
         }
