@@ -17,8 +17,16 @@ test_that("bru: clinear component", {
     data = input.df
   )
 
-  expect_equal(fit$summary.random[["myLin"]][1, "mean"], 2.002517, tolerance = midtol)
-  expect_equal(fit$summary.random[["myLin"]][1, "sd"], 0.01269209, tolerance = midtol)
+  expect_equal(
+    fit$summary.random[["myLin"]][1, "mean"],
+    2.002517,
+    tolerance = midtol
+  )
+  expect_equal(
+    fit$summary.random[["myLin"]][1, "sd"],
+    0.013,
+    tolerance = hitol
+  )
 
   pr <- predict(
     fit,
